@@ -2,6 +2,7 @@
 simulate_multi.py
     Script to run the BMCTool simulation based on a seq-file and a *.yaml config file.
 """
+import copy
 import numpy as np
 from os import path
 from pathlib import Path
@@ -21,8 +22,8 @@ def simulate_multi(config_file: (str, Path) = None, seq_file: (str, Path) = None
         config_file = Path(path.dirname(__file__)) / 'library' / 'sim-library' / 'config_wasabiti.yaml'
 
     if seq_file is None:
-        # seq_file = Path(path.dirname(__file__)) / 'library' / 'WASABITI_3T_3p75uT_5ms_48rect_vary_trec_sim.seq'
-        seq_file = Path(path.dirname(__file__)) / 'library' / 'seq-library' / 'WASABITI_sim.seq'
+        seq_file = Path(path.dirname(__file__)) / 'library' / 'WASABITI_3T_trec_1p5_sim_broken.seq'
+        # seq_file = Path(path.dirname(__file__)) / 'library' / 'seq-library' / 'WASABI.seq'
 
     # load config file(s)
     sim_params = load_params(config_file)
@@ -53,9 +54,9 @@ def simulate_multi(config_file: (str, Path) = None, seq_file: (str, Path) = None
 
         # extract and plot z-spectrum
         offsets, mz = sim.get_zspec(return_abs=True)
-        spec_list.append(mz[1:])
+        spec_list.append(mz)
 
-    return offsets[1:], spec_list, vary_vals
+    return offsets, spec_list, vary_vals
 
 
 if __name__ == '__main__':
